@@ -635,7 +635,7 @@ def checkPrerequisites():
 
 @app.callback()
 def callback(
-    verbosity: int = typer.Option(0, "--verbosity", "-v", help="Verbosity"),
+    verbosity: bool = typer.Option(False, "--verbosity", "-v", help="Verbosity"),
     debug: bool = typer.Option(False, "--debug", "-d", help="Enable Debugging"),
     environment: str = typer.Option(
         "development", "--environment", "-e", help="Environment"
@@ -645,7 +645,7 @@ def callback(
     ),
 ):
     backplane["verbosity"] = verbosity
-    backplane["environment"] = os.getenv("backplane['environment']", "development")
+    backplane["environment"] = os.getenv("BACKPLANE_ENVIRONMENT", environment)
     backplane["config_dir"] = os.getenv(
         "BACKPLANE_CONIG_DIR", os.path.join(os.getenv("HOME", "~"), ".backplane")
     )
@@ -661,6 +661,24 @@ def callback(
 
     checkPrerequisites()
 
+    if backplane["verbosity"] > 0:
+        typer.secho(f"backplane v1.2.0", err=False, fg=typer.colors.BRIGHT_BLACK)
+        typer.secho(
+            f"Environment: {backplane['environment']}",
+            err=False,
+            fg=typer.colors.BRIGHT_BLACK,
+        )
+        typer.secho(
+            f"Context: {backplane['active_context']}",
+            err=False,
+            fg=typer.colors.BRIGHT_BLACK,
+        )
+        typer.secho(
+            f"Context Directory: {backplane['active_context_dir']}",
+            err=False,
+            fg=typer.colors.BRIGHT_BLACK,
+        )
+
 
 if __name__ == "__main__":
     app()
